@@ -207,7 +207,7 @@ Rd2roxygen = function(pkg, nomatch, usage = FALSE) {
     for (i in tryf) {
       r = file.path(R.dir, i)
       idx = grep(sprintf('^[[:space:]]*(`|"|\'|)(%s)(\\1)[[:space:]]*(<-|=)',
-                          gsub('\\.', '\\\\.', fname)),
+                          gsub('([][{}()+*^$|?.])', '\\\\\\1', fname)),
                   (r.Rd = readLines(r, warn = FALSE)))
       message('  ', i, ': ', appendLF = FALSE)
       message(ifelse(length(idx), paste('line', idx), 'not found'))
